
Geo Handling Capabilities
=========================

For a complete treatment, please visit the `geo notebook`_.

.. _geo notebook: https://github.com/carlomazzaferro/scikit-hts-examples/blob/master/notebooks/geo.ipynb